#[non_exhaustive]pub enum Error {
Show 17 variants
InvalidFrameSize,
InvalidMetadata,
UnsupportedVersion,
UnsupportedSchemaVersion,
CompressionUnavailable,
EncryptionUnavailable,
InvalidRange,
FrameAfterFinal,
InvalidStoredLength,
ProfileMismatch,
UsageLimit,
Overflow,
Allocation,
CompressionFailed,
DecompressionFailed,
EncryptionFailed,
AuthenticationFailed,
}Expand description
A format, resource, or transformation failure. No I/O is performed by CRAFT.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InvalidFrameSize
A zero or unsupported maximum frame length.
InvalidMetadata
A length, count, profile, or index is inconsistent.
UnsupportedVersion
This metadata format version is not supported.
UnsupportedSchemaVersion
Only the metadata schema introduced in craft-codec 0.2.0 is supported.
The metadata requires a compression codec whose feature is disabled.
The metadata requires an encryption codec whose feature is disabled.
InvalidRange
The logical range is reversed or outside the object.
FrameAfterFinal
A full frame was submitted after a short final frame.
InvalidStoredLength
The buffer does not have the expected stored length.
ProfileMismatch
The descriptor and the decoder use different configurations.
UsageLimit
The configured cryptographic usage limit was reached.
Overflow
An integer or platform buffer limit would be exceeded.
Allocation
A buffer or index allocation failed.
CompressionFailed
The compression operation failed.
DecompressionFailed
Invalid compressed bytes or an incorrect decoded length.
EncryptionFailed
Encryption failed.
AuthenticationFailed
The frame did not authenticate.