pub enum Framing {
Fixed(u64),
Variable(u64),
}Expand description
Logical frame boundaries, before compression or encryption.
Variants
Fixed(u64)
All frames have this size, except a possibly shorter final frame.
Variable(u64)
Each nonempty frame may have any size up to this limit.
Implementations