pub struct Config { /* private fields */ }Expand description
Validated object-wide settings, including all codec initialization parameters.
Implementations
Sourceimpl Config
impl Config
Sourcepub fn new(
framing: Framing,
compression: Compression,
encryption: Encryption,
) -> Result<Self>
pub fn new( framing: Framing, compression: Compression, encryption: Encryption, ) -> Result<Self>
Validate a profile, including platform, codec and AES usage limits. Metadata for disabled codecs may still be inspected with this type.
Sourcepub const fn compression(&self) -> Compression
pub const fn compression(&self) -> Compression
Compression format.
Sourcepub const fn encryption(&self) -> &Encryption
pub const fn encryption(&self) -> &Encryption
Encryption format.
Sourcepub const fn max_frame_len(&self) -> u64
pub const fn max_frame_len(&self) -> u64
Maximum raw length, in bytes.
Sourcepub fn max_frames(&self) -> u64
pub fn max_frames(&self) -> u64
Maximum frame slots for this profile. AES reserves the configured maximum length for each slot, even if an actual frame is shorter.